# Wagtail Site Check Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

- ...

## [0.0.1] - 2023-10-04

- Initial release.


[unreleased]: https://github.com/wagtail-nest/wagtail-font-awesome-svg/compare/0.0.1...HEAD
[0.0.1]: https://github.com/allcaps/wagtail-site-check/compare/475414d613d433b7ac10e1dbb605f5d6ad83a77b...0.0.1
